@@ -2,19 +2,11 @@
 #! coding=utf-8
 
 APP_TITLE="pyKake"
-APP_VERSION="0.5.0"
+APP_VERSION="0.6.0"
 CONFPATH = "/apps/Maemo/%s/" % APP_TITLE.lower()
 LOGO = '/opt/pykake/pykake.png'
 
-import gtk
-import hildon
-import subprocess
-import gobject
-import time
-import gconf
-import gst
-import threading
-import pango
+import gtk, hildon, subprocess, gobject, time, gconf, gst, threading, pango
 
 # Global variables
 CURRENT_REMOTETYPE= ""
@@ -29,7 +21,7 @@ minutes = 0 # How many minutes user wants to keep shutter open in bulb
 seconds = 0.0   # If need some Seconds more in bulb mode :p
 timeSeconds = 0.0 # control timers beeb time
 globURI = "" # File to play
-beebRun = False # Duck tape solution
+beebRun = False # Duct tape solution
 gobjid = 0
 
 # Layouting
@@ -37,16 +29,46 @@ fontLabel = pango.FontDescription("Sans 20")
 fontButt = pango.FontDescription("Sans Bold 25")
 fontTimer = pango.FontDescription("Monotype Bold 35")
 
+# Texts, used in program
+LICENCE = """This program is free software: you can redistribute it and/or
+modify it under the terms of the GNU General Public License as
+published by the Free Software Foundation, either version 3 of
+the License, or (at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
+PURPOSE.  See the GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public
+License along with this program.   If not, see
+<http://www.gnu.org/licenses/>."""
+
+SETTINGS = """In settings you can change between camera manufacturers and interval of sound notice in Bulb timer. Sound notice is played when selected amount of time is ellapsed, default setting of this is 30 seconds. You can also turn restart notify in start up on and off."""
+
+BASIC = """In this mode you can take photos, just click the "Shutter" button. For Canon, there is also "Activate/Deactivate 2sec mode" button, when it is activated, photos with 2 seconds interval can be taken (in other manufacturers you had to select this function from camera)."""
+
+BULB = """\nThis is front end to take photos with Bulb. As default timer will count up and it will play sound notify when selected time is elapsed. You can also set it counting down and it will play sound when time is up. \nThe app won't send the end command to the camera automatically so you had to do it yourself, with Bulb off button. Timer don't understand 2 sec delay, so you must to count it by yourself.\n"""
+
+VIEWER = """Viewer is only available for Olympus. You can use this to remote control your camera in View mode to zoom and change photos. This is handy if you watch pictures in TV."""
+
+REMOTES = """Currently pyKake support following remotes from manufacturers them:\n   Canon: RC-1\n   Nikon: ML-L3\n   Olympus: RM-1\n   Pentax: RC-F"""
+
+MESSAGE = """If this is first time you use pyKake after install, it is possible that you need to restart the device before pyKake can send infrared signals. To test this, put your camera in live view mode, aim the device to the camera and press shutter button in pyKake, if you don't se light plinking in infrared port, you need to restart."""
+
 class pykakeGui:
     def __init__(self):
-	 global CURRENT_REMOTETYPE, TIME2BEEB
-	 miscFuncs().controlLircd("start") # Start Lirc in start-up
-	 # Loading needed info from gconf
-	 CURRENT_REMOTETYPE = miscFuncs().confReader("remote")
-	 TIME2BEEB = miscFuncs().confReader("beebtime")
-	 self.mainWindow()
-	 if not CURRENT_REMOTETYPE and not TIME2BEEB: # Opening settings dialog, if first start
+	global CURRENT_REMOTETYPE, TIME2BEEB
+	miscFuncs().controlLircd("start") # Start Lirc in start-up
+	# Loading needed info from gconf
+	CURRENT_REMOTETYPE = miscFuncs().confReader("remote")
+	TIME2BEEB = miscFuncs().confReader("beebtime")
+	self.mainWindow()
+	if not CURRENT_REMOTETYPE and not TIME2BEEB: # Opening settings dialog, if first start
 	    self.settingsDialog("open")
+	helpfile = miscFuncs().confReader("help_show")
+	if helpfile != "False":
+	    dialogWindows().messageDialog("open")
 
     # WINDOWS
     def mainWindow(self):  # Window to select between modes
@@ -77,7 +99,8 @@ class pykakeGui:
 	self.butt3.connect('clicked', self.viewerMode, None)
 	vbox.pack_start(self.butt3, True, True, 0)
 	win.show_all()
-	self.buttControl()
+	if CURRENT_REMOTETYPE != "Olympus_RM-1":
+	    self.butt3.hide()
 
     def singleShot(self, widget, data): # Mode to just take photos
 	win = hildon.StackableWindow()
@@ -102,7 +125,8 @@ class pykakeGui:
 	self.buttMod2sec.connect('clicked', self.mode2sec,"5")
 	hbox.pack_start(self.buttMod2sec, True, True, 0)
 	win.show_all()
-	self.buttControl()
+	if CURRENT_REMOTETYPE != "CANON-RC1/RC5":
+	    self.buttMod2sec.hide()
 
     def bulbMode(self, widget, data): # Mode to use bulb
 	win = hildon.StackableWindow()
@@ -139,7 +163,8 @@ class pykakeGui:
 	self.buttMod2sec.connect('clicked', self.mode2sec, "8")
 	vbox2.pack_start(self.buttMod2sec, True, True, 0)
 	win.show_all()
-	self.buttControl()
+	if CURRENT_REMOTETYPE != "CANON-RC1/RC5":
+	    self.buttMod2sec.hide()
 
     def viewerMode(self,widget,data): # Mode to show photos remotely
 	win = hildon.StackableWindow()
@@ -206,11 +231,15 @@ class pykakeGui:
 	menu.append(mbutt1)
 	mbutt2 = hildon.GtkButton(gtk.HILDON_SIZE_AUTO)
 	mbutt2.set_label("About")
-	mbutt2.connect('clicked', self.aboutDialog)
+	mbutt2.connect('clicked', dialogWindows().aboutDialog)
 	menu.append(mbutt2)
+	mbutt3 = hildon.GtkButton(gtk.HILDON_SIZE_AUTO)
+	mbutt3.set_label("Help")
+	mbutt3.connect('clicked', dialogWindows().helpDialog)
+	menu.append(mbutt3)
 	menu.show_all()
 	return menu
-
+	
     def settingsDialog(self, widget):
 	global CURRENT_REMOTETYPE, TIME2BEEB
 	settings = gtk.Dialog("Settings", None, gtk.DIALOG_DESTROY_WITH_PARENT | gtk.DIALOG_NO_SEPARATOR)
@@ -242,7 +271,7 @@ class pykakeGui:
 	elif CURRENT_REMOTETYPE == "Pentax_RC-F":
 	    pentax.set_active(True)
 	else:
-	    olympus.set_active(True) # Default
+	    canon.set_active(True) # Default
 
 	label1 = gtk.Label("Select camera:")
 
@@ -287,7 +316,16 @@ class pykakeGui:
 	hbox2.pack_start(t1min, True, True, 0)
 	hbox2.pack_start(t10min, True, True, 0)
 	hbox2.pack_start(tOff, True, True, 0)
-
+	
+	label = gtk.Label("")
+	vbox.pack_start(label, True, True, 0)
+	bool = dialogWindows().checkStatus()
+	message = hildon.CheckButton(gtk.HILDON_SIZE_FINGER_HEIGHT)
+	message.set_label("Show restart notify in start up")
+	message.set_active(bool)
+	message.connect("clicked", dialogWindows().checkButton)
+	vbox.pack_start(message, True, True, 0)	
+	
 	settings.vbox.add(selector)
 	settings.show_all()
 	response = settings.run()
@@ -318,35 +356,7 @@ class pykakeGui:
 	    self.buttControl() # Show hide buttons, if needed
 
 	settings.destroy()
-
-    def aboutDialog(self, widget):
-	about = gtk.AboutDialog()
-	about.set_title("About")
-	about.set_name(APP_TITLE)
-	about.set_version(APP_VERSION)
-	about.set_copyright("Copyright 2010 Janne Pekkala")
-	about.set_authors(["Janne Pekkala <yabbapappa@gmail.com>",""])
-	about.set_artists(["Icon: Tomi Taipaleenmäki",""])
-	about.set_logo(gtk.gdk.pixbuf_new_from_file(LOGO))
-	about.set_comments("All logos and trademarks are property of their respective owners and are used for informational purposes only.")
-	about.set_license( """This program is free software: you can redistribute it and/or
-modify it under the terms of the GNU General Public License as
-published by the Free Software Foundation, either version 3 of
-the License, or (at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-PURPOSE.  See the GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public
-License along with this program.   If not, see
-<http://www.gnu.org/licenses/>.""")
-	#set_wrap_license(True)
-	about.show_all()
-	about.run()
-	about.destroy()
-
+	
     def main(self):
 	gtk.main()
 
@@ -498,18 +508,114 @@ License along with this program.   If not, see
 	self.timerLabel.modify_font(fontTimer)
 	return True
 
+class dialogWindows:
+    def messageDialog(self, widget):
+	message = gtk.Dialog("Important!", None, gtk.DIALOG_DESTROY_WITH_PARENT | gtk.DIALOG_NO_SEPARATOR)
+	close = message.add_button(gtk.STOCK_CLOSE, gtk.RESPONSE_DELETE_EVENT)
+	vbox = gtk.VBox(False, 0)
+	label = gtk.Label()
+	label.set_markup(MESSAGE)
+	label.set_line_wrap(True)
+	vbox.pack_start(label, True, True, 0)
+
+	bool = self.checkStatus()	
+	dbutt = hildon.CheckButton(gtk.HILDON_SIZE_FINGER_HEIGHT)
+	dbutt.set_label("Show this message in start up")
+	dbutt.set_active(bool)
+	dbutt.connect("clicked", self.checkButton)
+	vbox.pack_start(dbutt, False, False, 0)	
+	
+	message.vbox.add(vbox)
+	message.show_all()
+	response = message.run()
+	if response == gtk.RESPONSE_DELETE_EVENT:
+	    message.destroy()
+    
+    def checkStatus(self):
+	bool = miscFuncs().confReader("help_show")
+	if bool == "True":
+	    bool = True
+	elif bool == "False":
+	    bool = False
+	else: # Failback for if bool == None a.k.a first run.
+	    bool = True
+	    miscFuncs().confAdder("help_show", bool) # Adds the default boolean to gconf
+	return bool
+
+    def checkButton(self, widget):
+	bool = miscFuncs().confReader("help_show")
+	if bool == "True":
+	    new = False
+	else:
+	    new = True
+	miscFuncs().confAdder("help_show", new)    
+
+    def helpDialog(self, widget):
+	help = gtk.Dialog("Help", None, gtk.DIALOG_DESTROY_WITH_PARENT | gtk.DIALOG_NO_SEPARATOR)
+	
+	# Settings:
+	title1 = gtk.Label("Settings")
+	setted = gtk.Label(SETTINGS)
+	setted.set_line_wrap(True)
+	
+	# Basic:
+	title2 = gtk.Label("Basic mode")
+	basica = gtk.Label(BASIC)
+	basica.set_line_wrap(True)
+	
+	# Bulb:
+	title3 = gtk.Label("Bulb mode")
+	bulber = gtk.Label(BULB)
+	bulber.set_line_wrap(True)
+	
+	# Viewer:
+	title4 = gtk.Label("Viewer mode")
+	viewings = gtk.Label(VIEWER)
+	viewings.set_line_wrap(True)
+	
+	# Support:
+	title5 = gtk.Label("Supported cameras")
+	remotes = gtk.Label(REMOTES)
+	remotes.set_line_wrap(True)
+	
+	notes = gtk.Notebook()
+	notes.set_tab_pos(gtk.POS_TOP)
+	notes.append_page(setted, title1)
+	notes.append_page(basica, title2)
+	notes.append_page(bulber, title3)
+	notes.append_page(viewings, title4)
+	notes.append_page(remotes, title5)
+	
+	help.vbox.add(notes)
+	help.show_all()
+	response = help.run()
+	help.destroy()
+
+    def aboutDialog(self, widget):
+	about = gtk.AboutDialog()
+	about.set_title("About")
+	about.set_name(APP_TITLE)
+	about.set_version(APP_VERSION)
+	about.set_copyright("Copyright 2010 Janne Pekkala")
+	about.set_authors(["Janne Pekkala <yabbapappa@gmail.com>",""])
+	about.set_artists(["Icon: Tomi Taipaleenmäki",""])
+	about.set_logo(gtk.gdk.pixbuf_new_from_file(LOGO))
+	about.set_comments("All logos and trademarks are property of their respective owners and are used for informational purposes only.")
+	about.set_license(LICENCE)
+	about.show_all()
+	about.run()
+	about.destroy()
+
 class player (threading.Thread):
     def run(self):
 	global beebRun
 	player = gst.element_factory_make("playbin","player")
-	print "Playing: ",globURI
 	player.set_property('uri', globURI)
 	player.set_state(gst.STATE_PLAYING)
 	time.sleep(3)
 	beebRun = False
 
 class digitalCamera: # This is class where commands from GUI are translated ready to be send to camera
-    #CAMERAS
     def olympus(self,rawdata):
 	comDict = {"shutter":"capture" , "bulbon":"W" , "bulboff":"T" , "zoomin":"T" , "zoomout":"W" , "previous":"-" , "next":"+"}
 	cmd = comDict[rawdata]
@@ -526,14 +632,10 @@ class digitalCamera: # This is class where commands from GUI are translated read
     def pentax(self, data):
 	if data == "bulbon":
 	    """ Sending start command in bulb mode """
-#	    print "Pentax - Bulb on."
 	    self.bulbPatchPentax("start")
-
 	elif data == "bulboff":
 	    """ Sending stop command in bulb mode """
-#	    print "Pentax - Bulb off"
 	    self.bulbPatchPentax("stop")
-
 	else:
 	    """ Sending normal shutter command. """
 	    cmd = "Capture"
@@ -555,19 +657,15 @@ class digitalCamera: # This is class where commands from GUI are translated read
 	shoot = subprocess.Popen (arg, stdin = subprocess.PIPE)
 	shoot.stdin.close()
 	shoot.wait()
-	# Need some kind of failback system + some info (more than what camera it self gives, example some kind of sound played after send.
 
     def bulbPatchPentax(self, state):
 	remote = CURRENT_REMOTETYPE
 	code = "Capture"
 	if state == "start":
-	    """ Start send the signal """
 	    directive = "send_start"
 	elif state == "stop":
-	    """ Stop send the signal """
 	    directive = "send_stop"
 	else:
-	    """ Something failed in getting state of bulb, only sending command once. """
 	    directive = "send_once"
 	arg = ["/usr/bin/irsend", directive, remote, code]
 	shoot = subprocess.Popen (arg, stdin = subprocess.PIPE)
@@ -583,7 +681,6 @@ class miscFuncs: # Some miscaleous functions (For the sake of simplicity
 
     # GCONF FUNCS
     def confReader(self, target): # To get data
-	global CONFPATH
 	client = gconf.client_get_default()
 	client.add_dir(CONFPATH, gconf.CLIENT_PRELOAD_NONE)
 	try:
@@ -596,7 +693,7 @@ class miscFuncs: # Some miscaleous functions (For the sake of simplicity
 	return data
 
     def confAdder(self, target, data): # To put data
-	global CONFPATH, CURRENT_REMOTETYPE, TIME2BEEB
+	global CURRENT_REMOTETYPE, TIME2BEEB
 	client = gconf.client_get_default()
 	client.add_dir(CONFPATH, gconf.CLIENT_PRELOAD_NONE)
 	try:
